Globals — Pykaryote 1.1.0d documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pykaryote 1.1.0d documentation »
- Modules »

# Globals

## Overview

The globals module is the bridge between configuration files and simulations. Before a `Simulation` is created, globals must be initialized using `init_globals()`.

For a listing of all global variables, see Configuration Options

## Documentation

Globals loads settings from simulation configuration files.

Settings are loaded into an object called `settings` Typical usage:

    from pykaryote.utils.globals import settings as gv
    gv.init_globals(path_to_sim_cfg)
    x = gv.generation_limit

Configuration files have a weird, hackish syntax as a result of poor design decisions early on. They are a mixture of INI and psudo-json. For more information on simulation configuration file format, see the section of that name in the reference documentation.

Ideally, config files would be converted to use pure JSON, but then backwards compatibility with old config files would be lost.

### Navigation

- index
- modules |
- next |
- previous |
- Pykaryote 1.1.0d documentation »
- Modules »